// Import the standard GUI elements from QTQuick
import QtQuick 2.2
import QtQuick.Controls 1.1
import QtQuick.Controls.Styles 1.1
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.1
import QtQuick.Window 2.2

// Import the Uranium GUI elements, which are themed for Cura
import UM 1.1 as UM
import Cura 1.0 as Cura

// Dialog
Window
{
    id: base

    title: "Print Continue"

    color: "#fafafa" //Background color of cura: #fafafa

    // We don't want the dialog to block input in the main window
    modality: Qt.NonModal

    //We want the window to stay on top
    flags: Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint | Qt.WindowCloseButtonHint

    // Setting the dimensions of the dialog window and prohibiting resizing
    width: 300
    height: 150
    minimumWidth: 350
    minimumHeight: 150

    //Position the window
    x: Screen.width - width - 50
    y: 400

    //This is for giving the Window a boarder and a background color
    Rectangle {
        id: bg_rect
        width: 300
        height: 140
        color: "#fff"
        border.color: "#ededed"
        border.width: 2
        radius: 5
    }


    // Connecting our variable to the computed property of the manager
    property string userInfoText: manager.userInfoText

    //This Button is for closing the dialog
    Button
    {
        id: close_button
        text: "<font color='#ffffff'>" + "x" + "</font>"
        width: 25
        height: 25

        anchors.top: parent.top
        anchors.topMargin: 10
        anchors.right: parent.right
        anchors.rightMargin: 10

        tooltip: "close this dialog"

        style: ButtonStyle{
            background: Rectangle {
                implicitWidth: 100
                implicitHeight: 25
                radius: 3
                color: "#D22"
            }
        }

        onClicked:
        {
            base.close();
        }

    }


    //Text "Height: "
    Text
    {
        id: text_height1
        text: "Height:"
        font.family: "Helvetica"
        font.pointSize: 15
        color: "#131151"

        anchors.top: close_button.top
        anchors.topMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 10
    }

    //User input of height
    TextField
    {
        id: height_input
        width: 80
        text: ""
        placeholderText: "e.g. 12.2"

        anchors.bottom: text_height1.bottom
        anchors.bottomMargin: 0
        anchors.left: text_height1.right
        anchors.leftMargin: 10

        font.pointSize: 11

        //The window musn't close when enter is pressed
        Keys.onReturnPressed:
        {
            event.accepted = true
        }

        //Return the new entered value
        Keys.onReleased:
        {
            manager.heightEntered(height_input.text)
        }
    }

    //Text: "mm"
    Text
    {
        id: text_height2
        text: "mm"
        font.family: "Helvetica"
        font.pointSize: 15
        color: "#131151"

        anchors.bottom: text_height1.bottom
        anchors.bottomMargin: 0
        anchors.left: height_input.right
        anchors.leftMargin: 5
    }

    //This Button only exists to hold the help Tooltip
    Button
    {
        id: help_button
        text: "<font color='#888'>" + "?" + "</font>"
        //text: "?"
        width: 21
        height: 21

        anchors.bottom: close_button.bottom
        anchors.bottomMargin: 2
        anchors.right: close_button.left
        anchors.rightMargin: 5

        tooltip:
        "This plugin helps you to continue an aborted print.
        Make sure your printed part does't interfere with the leveling!
            1) Don't remove your old print from the base. Clean the edge.
            2) Measure the precise height where your print stopped.
            3) Load the gCode you where printing.
            4) Enter that value in the field on the left.
            5) Make sure your height is right by previewing it.
            6) Generate the missing gCode and save it.
            7) Continue your print by using the new gCode!"

        onClicked:
        {
            //do button action
            manager.buttonHelpPressed()
        }

        style: ButtonStyle{
            background: Rectangle {
                implicitWidth: 15
                implicitHeight: 15
                radius: 10
                color: "#fafafa"
                border.width: 1
                border.color: "#888"
            }
        }

    }



    //Button <Preview>
    Button
    {
        id: button_preview
        text: "Preview"
        width: 80
        height: 40
        tooltip: "Previews the already printed part for comparison"

        anchors.top: text_height1.bottom
        anchors.topMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 10

        onClicked:
        {
            //read value from textfield to prevent bugs
            manager.heightEntered(height_input.text)
            //do button action
            manager.button2Pressed()
        }

    }

    //Button <Generate>
    Button
    {
        id: button_continue
        text: "Generate"
        width: 100
        height: 40
        tooltip: "generates the GCode for the missing part"

        anchors.top: button_preview.top
        anchors.topMargin: 0
        anchors.left: button_preview.right
        anchors.leftMargin: 10

        onClicked:
        {
            //read value from textfield, to prevent bugs
            manager.heightEntered(height_input.text)
            //do button action
            manager.button1Pressed()
        }
    }

    //Button <Original>
    Button
    {
        id: button_original
        text: "Original"
        width: 80
        height: 40
        tooltip: "restores the unchanged GCode"

        anchors.top: button_preview.top
        anchors.topMargin: 0
        anchors.left: button_continue.right
        anchors.leftMargin: 10



        onClicked:
        {
            //do button action
            manager.button3Pressed()
        }

    }



    //Textfield for User Messages
    Text
    {

        id: user_text

        width: 280
        anchors.top: button_continue.bottom
        anchors.topMargin: 10
        anchors.left: parent.left
        anchors.leftMargin: 10

        //text: "Hallo"
        text: userInfoText

        font.family: "Helvetica"
        font.pointSize: 11
        //The color gets overwritten by the html tags added to the text
        color: "black"

        wrapMode: Text.Wrap


    }

}
